@@ -12,7 +12,7 @@ Usage::
     session_client: OutpostsClient = session.client("outposts")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING
+from typing import Any, Dict, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_outposts.type_defs import (
     CreateOutpostOutputTypeDef,
@@ -27,24 +27,24 @@ __all__ = ("OutpostsClient",)
 
 
 class Exceptions:
-    AccessDeniedException: Boto3ClientError
-    ClientError: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    NotFoundException: Boto3ClientError
-    ServiceQuotaExceededException: Boto3ClientError
-    ValidationException: Boto3ClientError
+    AccessDeniedException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    InternalServerException: Type[Boto3ClientError]
+    NotFoundException: Type[Boto3ClientError]
+    ServiceQuotaExceededException: Type[Boto3ClientError]
+    ValidationException: Type[Boto3ClientError]
 
 
 class OutpostsClient:
     """
-    [Outposts.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client)
+    [Outposts.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.can_paginate)
         """
 
     def create_outpost(
@@ -56,17 +56,17 @@ class OutpostsClient:
         AvailabilityZoneId: str = None,
     ) -> CreateOutpostOutputTypeDef:
         """
-        [Client.create_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.create_outpost)
+        [Client.create_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.create_outpost)
         """
 
     def delete_outpost(self, OutpostId: str) -> Dict[str, Any]:
         """
-        [Client.delete_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.delete_outpost)
+        [Client.delete_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.delete_outpost)
         """
 
     def delete_site(self, SiteId: str) -> Dict[str, Any]:
         """
-        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.delete_site)
+        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.delete_site)
         """
 
     def generate_presigned_url(
@@ -77,29 +77,29 @@ class OutpostsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
         """
 
     def get_outpost(self, OutpostId: str) -> GetOutpostOutputTypeDef:
         """
-        [Client.get_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.get_outpost)
+        [Client.get_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.get_outpost)
         """
 
     def get_outpost_instance_types(
         self, OutpostId: str, NextToken: str = None, MaxResults: int = None
     ) -> GetOutpostInstanceTypesOutputTypeDef:
         """
-        [Client.get_outpost_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
+        [Client.get_outpost_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
         """
 
     def list_outposts(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListOutpostsOutputTypeDef:
         """
-        [Client.list_outposts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.list_outposts)
+        [Client.list_outposts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.list_outposts)
         """
 
     def list_sites(self, NextToken: str = None, MaxResults: int = None) -> ListSitesOutputTypeDef:
         """
-        [Client.list_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/outposts.html#Outposts.Client.list_sites)
+        [Client.list_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/outposts.html#Outposts.Client.list_sites)
         """
